@@ -267,6 +267,9 @@ meta_window_menu_new   (MetaFrames         *frames,
 
   if (n_workspaces < 2)
     ops &= ~(META_MENU_OP_STICK | META_MENU_OP_UNSTICK | META_MENU_OP_WORKSPACES);
+  else if (n_workspaces == 2) 
+    /* #151183: If we only have two workspaces, disable the menu listing them. */
+    ops &= ~(META_MENU_OP_WORKSPACES);
   
   menu = g_new (MetaWindowMenu, 1);
   menu->frames = frames;
